function asbsfilter ( filename, cut )
%%
% ASBSFILTER(FILENAME,CUT)
%
% Purpose:  apply high pass filter and
%           saves results as a .wav file ending with cXX, where XX is
%           the cut frequency.
%
% Inputs:   filename    - source wave file
%           cut         - cut frequency
%            
% Output:   none
%
% Author:   juan a. Castro
% Version:  1.0 jan/2015
%%

[path name ext] = fileparts (filename);
if isempty( ext )
    filename = [filename '.wav'];
end

% read audio file
[x fs nbits] = wavread(filename); 

% Calculate zeros and poles of a elliptic filter 
[b a] = ellip (6, 0.1, 50, 2 * cut / fs, 'high');
% apply filter
y = filter (b, a, x);

pos = strfind(filename, '_');

if isempty(pos)
    filename = [strrep(filename, '.wav', ['_c' int2str(cut) '.wav'])];
else
    filename = [filename(1:pos) 'c' int2str(cut) filename(pos+1:end)];
end    
       
% save filtered wave as new file 
wavwrite(y, fs, nbits, filename); 

%% EOF
