function [ features ] = asbsframefeatures( frame, feature )
%%
% ASBSFRAMEFEATURES(FRAME,FEATURE)
%
% Purpose:  returns value of chosen features from a frame
%
% Inputs:   frame       - frame to process 
%           feature     - feature(s) to extract
%           
% Output:   features    - vector with selectec features
%
% Author:   juan a. Castro
% Version:  1.0 jan/2015
%%

global ASBS_THRESHOLD;
global ASBS_NFFT;
global ASBS_CENTROID;
global ASBS_FLATNESS;
global ASBS_ROLLOFF;
global ASBS_ZCR;
global ASBS_MFCC;
global ASBS_RMSRATIO;
global ASBS_WINDOW_SAMPLES;

global ASBS_I_RMS;            % RMS
global ASBS_I_CENTROID;       % Spectrum Centroid
global ASBS_I_FLATNESS;       % Spectrum Flatness
global ASBS_I_ROLLOFF;        % Spectrum RollOff;
global ASBS_I_ZCR;            % Signal Zero-cross rating
global ASBS_I_MFCC2;          
global ASBS_I_MFCC13;         
global ASBS_I_RMSRATIO;
global ASBS_TOTAL_FEATURES;

% set output dimensions
features = zeros (1, ASBS_TOTAL_FEATURES);

% Calculates frame energy
e = asbssignalrms( frame );

% Allways obtain energy
features(1, ASBS_I_RMS) = e;

% chech if we need to process the frame

if (e >= ASBS_THRESHOLD)
    %% FEATURES EXTRACTION
    % ZERO-CROSSING RATE
    if bitand( feature, ASBS_ZCR ) > 0
        features(1, ASBS_I_ZCR) = asbszerocross( frame );
    end
    if bitand ( feature, ASBS_CENTROID ) > 0 | ...
       bitand ( feature, ASBS_FLATNESS ) > 0 | ...
       bitand ( feature, ASBS_ROLLOFF ) > 0 | ...
       bitand ( feature, ASBS_MFCC ) > 0 | ...
       bitand ( feature, ASBS_RMSRATIO ) > 0
       
        %% FREQUENCY DOMAIN FEATURES
%        N = length(frame);
        % apply hamming window    
        xh = frame.*hamming(ASBS_WINDOW_SAMPLES);    
%        NFFT = 2^nextpow2(N);       % length of FFT
        X1 = fft (xh, ASBS_NFFT);        % spectrum of X
        X = X1 / ASBS_WINDOW_SAMPLES;
        XX = 2*abs(X(1 : ASBS_NFFT / 2 + 1)); % Spectrum magnitud

        % SPECTRAL CENTROID
        if bitand ( feature, ASBS_CENTROID ) > 0
            features(1, ASBS_I_CENTROID) = ...
                                asbscentroid(XX) / length (XX);
        end
        
        % SPECTRAL FLATNESS
        if bitand ( feature, ASBS_FLATNESS ) > 0
            features(1, ASBS_I_FLATNESS) = asbsflatness(XX);
        end

        % SPECTRAL ROLLOFF     
        if bitand ( feature, ASBS_ROLLOFF ) > 0
            features(1, ASBS_I_ROLLOFF) = ...
                                asbsrolloff(XX, 0.85) / length(XX);
        end
        
        % MFCC
        if bitand ( feature, ASBS_MFCC ) > 0
            features(1, ASBS_I_MFCC2:ASBS_I_MFCC13) = ...
                                asbsmfcc(abs(X1))'; %% X1 !!
        end
            
        % RMS RATIO AT 2000 Hz     
        if bitand ( feature, ASBS_RMSRATIO ) > 0
            features(1, ASBS_I_RMSRATIO) = asbsrmsratio(XX, 2000);
        end
    end     % spectrum feature
end % if energy > threshold

%% EOF
