function asbsinit ( fs, ws )
%%
% ASBSINIT(FS,WS)
%
% Purpose:  Performs global inititializations. It must be called before
%           using any other functions. It performs generic calculations
%           so that it saves computation time.
%
% Inputs:   fs          - sample rate
%           ws          - window size
%           
% Output:   nothing
%
% Author:   juan a. Castro
% Version:  1.0 jan/2015
%%

%% 
global ASBS_INITDONE;
ASBS_INITDONE = true;
%%

%% FRAME PROCESSING VARIABLES
global ASBS_SAMPLING;       % sampling frequency
global ASBS_WINDOW_SIZE;    % window size (s)
global ASBS_OVERLAPPED;     % true or false
global ASBS_THRESHOLD;      % RMS threshold
ASBS_SAMPLING       = fs;
ASBS_WINDOW_SIZE    = ws/1000;
ASBS_OVERLAPPED     = true;
ASBS_THRESHOLD      = 0.00125;
%%

%% PREFILTERING DATA
global ASBS_ELLIP_ORDER;    % order of elliptic filter
global ASBS_ELLIP_CUT;      % cut frequency of filter
global ASBS_ELLIP_ZEROS;    % zeros filter coefficients
global ASBS_ELLIP_POLES;    % poles filter coefficients
ASBS_ELLIP_CUT   = 100;
ASBS_ELLIP_ORDER = 6;
[ASBS_ELLIP_ZEROS ASBS_ELLIP_POLES] = ellip (ASBS_ELLIP_ORDER, ...
                                 0.1, 50, ...
                               2 * ASBS_ELLIP_CUT / ASBS_SAMPLING, ...
                                 'high');
%%

%% FEATURES VARIABLES
global ASBS_RMS;            % RMS
global ASBS_CENTROID;       % Spectrum Centroid
global ASBS_FLATNESS;       % Spectrum Flatness
global ASBS_ROLLOFF;        % Spectrum RollOff;
global ASBS_ZCR;            % Signal Zero-cross rating
global ASBS_MFCC2;          % MFCC 2
global ASBS_MFCC3;          % MFCC 3
global ASBS_MFCC4;          % MFCC 4
global ASBS_MFCC5;          % MFCC 5
global ASBS_MFCC6;          % MFCC 6
global ASBS_MFCC7;          % MFCC 7
global ASBS_MFCC8;          % MFCC 8
global ASBS_MFCC9;          % MFCC 9
global ASBS_MFCC10;         % MFCC 10
global ASBS_MFCC11;         % MFCC 11
global ASBS_MFCC12;         % MFCC 12
global ASBS_MFCC13;         % MFCC 13
global ASBS_MFCC;           % All MFCCs
global ASBS_RMSRATIO;       % RMS ratio at 2000Hz
global ASBS_ALLFEATURES;    % ALL FEATURES
ASBS_RMS            = bin2dec('1');
ASBS_CENTROID       = bin2dec('10');
ASBS_FLATNESS       = bin2dec('100');
ASBS_ROLLOFF        = bin2dec('1000');
ASBS_ZCR            = bin2dec('10000');
ASBS_MFCC2          = bin2dec('100000');
ASBS_MFCC3          = bin2dec('1000000');
ASBS_MFCC4          = bin2dec('10000000');
ASBS_MFCC5          = bin2dec('100000000');
ASBS_MFCC6          = bin2dec('1000000000');
ASBS_MFCC7          = bin2dec('10000000000');
ASBS_MFCC8          = bin2dec('100000000000');
ASBS_MFCC9          = bin2dec('1000000000000');
ASBS_MFCC10         = bin2dec('10000000000000');
ASBS_MFCC11         = bin2dec('100000000000000');
ASBS_MFCC12         = bin2dec('1000000000000000');
ASBS_MFCC13         = bin2dec('10000000000000000');
ASBS_MFCC           = bin2dec('11111111111100000');
ASBS_RMSRATIO       = bin2dec('100000000000000000');
ASBS_ALLFEATURES    = bin2dec('111111111111111111');

% Column indexes in features matrix
global ASBS_I_RMS;
global ASBS_I_CENTROID;
global ASBS_I_FLATNESS;
global ASBS_I_ROLLOFF;
global ASBS_I_ZCR;
global ASBS_I_MFCC2;
global ASBS_I_MFCC3;
global ASBS_I_MFCC4;
global ASBS_I_MFCC5;
global ASBS_I_MFCC6;
global ASBS_I_MFCC7;
global ASBS_I_MFCC8;
global ASBS_I_MFCC9;
global ASBS_I_MFCC10;
global ASBS_I_MFCC11;
global ASBS_I_MFCC12;
global ASBS_I_MFCC13;
global ASBS_I_RMSRATIO;
global ASBS_TOTAL_FEATURES;
global ASBS_I_EVENT;          % event
ASBS_I_RMS          = 1;
ASBS_I_CENTROID     = 2;
ASBS_I_FLATNESS     = 3;
ASBS_I_ROLLOFF      = 4;
ASBS_I_ZCR          = 5;
ASBS_I_MFCC2        = 6;
ASBS_I_MFCC3        = 7;
ASBS_I_MFCC4        = 8;
ASBS_I_MFCC5        = 9;
ASBS_I_MFCC6        = 10;
ASBS_I_MFCC7        = 11;
ASBS_I_MFCC8        = 12;
ASBS_I_MFCC9        = 13;
ASBS_I_MFCC10       = 14;
ASBS_I_MFCC11       = 15;
ASBS_I_MFCC12       = 16;
ASBS_I_MFCC13       = 17;
ASBS_I_RMSRATIO     = 18;
ASBS_TOTAL_FEATURES = 18;
ASBS_I_EVENT        = 19;
%%

%% MFCC PRE-CALCULATIONS
global ASBS_WINDOW_SAMPLES;
global ASBS_NFFT;
global ASBS_TRIFBANK;
global ASBS_DCT;
global ASBS_LIFTER;
ASBS_WINDOW_SAMPLES = floor(fs * ASBS_WINDOW_SIZE);
if ASBS_OVERLAPPED % Window samples must be even 
    ASBS_WINDOW_SAMPLES = round(ASBS_WINDOW_SAMPLES / 2) * 2;  
end
% REFER TO ASBSMFCC.M FOR LICENCE OF THE FOLLOWING CODE
ASBS_NFFT = 2^nextpow2(ASBS_WINDOW_SAMPLES);
% Handy inline function handles
% Forward and backward mel frequency warping
hz2mel = @( hz )( 1127*log(1+hz/700) );     % Hertz to mel warping func
mel2hz = @( mel )( 700*exp(mel/1127)-700 ); % mel to Hertz warping func
% Type III DCT matrix routine 
dctm = @( N, M )( sqrt(2.0/M) * cos( repmat([0:N-1].',1,M) ...
                                   .* repmat(pi*([1:M]-0.5)/M,N,1) ) );
% Cepstral lifter routine 
ceplifter = @( N, L )( 1+0.5*L*sin(pi*[0:N-1]/L) );
% Triangular filterbank with uniformly spaced filters on mel scale
M = 24; % number of filters in filterbank
N = 13; % number of cepstrals coeficients including el 0
R = [ 100 ASBS_SAMPLING/2 ];  % Freq range to consider for filterbank
K = ASBS_NFFT/2+1;            % length of the unique part of the FFT 
ASBS_TRIFBANK = trifbank( M, K, R, ASBS_SAMPLING, hz2mel, mel2hz );
% size of H is M x K 
% DCT matrix computation
ASBS_DCT = dctm( N, M );
% Cepstral lifter computation. Used to give coefficients similar
% magnitud order
L = 22;
ASBS_LIFTER = ceplifter( N, L ); 
%%

%% KNN Algorithm Data
global ASBS_MODELCODE;
global ASBS_ZMODEL;
global ASBS_MU;
global ASBS_DELTA;
ASBS_MODELCODE  = '';
ASBS_ZMODEL     = [];
ASBS_MU         = [];
ASBS_DELTA      = [];

%% EOF
