function output = asbsknnvalidate3 (modelcode, features )
%%
% ASBSKNNVALIDATE3(MODELCODE,FEATURES)
%
% Purpose:  Auxiliary function that performs cross-validation of a
%           repository
%           using kNN classification algorithm.
%
% Inputs:   modelcode   - Repository
%           features    - Chosen features to use in classification
%
% Output:   output      - matrix with real and predicted classes
%           
% Author:   juan a. Castro
% Version:  1.0 jan/2015
%%

global ASBS_I_EVENT;
global ASBS_ZMODEL;

asbsloadmodel( modelcode );

p = zeros(3,3);
for i=1:3
I = randperm(length(ASBS_ZMODEL));
L = floor(length(ASBS_ZMODEL)/3);

%% MAKE PARTITION
I = I((i-1)*L+1:i*L);
query = ASBS_ZMODEL(I,:);
% eliminar los que sale evento no definido
query = query(query( :, ASBS_I_EVENT)  ~= 0, : ); 
ASBS_ZMODEL(I,:)=[];

zquery = query; 

IFeatures = asbsfeatureindex (features);
[IDX d] = knnsearch(ASBS_ZMODEL(:,IFeatures), zquery(:,IFeatures));

nmatches1 = length(find(       ASBS_ZMODEL(IDX,ASBS_I_EVENT)    ==...
                                query(:,ASBS_I_EVENT)     ));
nmatches2 = length(find( ceil (ASBS_ZMODEL(IDX,ASBS_I_EVENT)/2) ==...
                                ceil(query(:,ASBS_I_EVENT)/2)  ));
nmatches3 = length(find( rem  (ASBS_ZMODEL(IDX,ASBS_I_EVENT),2) ==...
                                rem (query(:,ASBS_I_EVENT), 2) ));
percent1 = nmatches1 / length(query);
percent2 = nmatches2 / length(query);
percent3 = nmatches3 / length(query);

p(i, 1) = percent1;
p(i, 2) = percent2;
p(i, 3) = percent3;

end
%% outputs
output = [query(:,ASBS_I_EVENT) ASBS_ZMODEL(IDX,ASBS_I_EVENT)];

disp(['MEAN: ' num2str(mean (p)*100)]);
disp(['STD : ' num2str(std (p)*100)]);

%% EOF

