function asbsplotfeature( wavefile, feature, withlegend )
%%
% ASBSPLOTFEATURE(WAVEFILE, FEATURE, WITHLEGEND)
%
% Purpose:  Auxiliary function that plots feature from wavefile
%
% Inputs:   wavefile is the signal
%           feature to plot
%           withlegend? (true/false)
%
% Output:   nothing
%
% Author:   juan a. Castro
% Version:  1.0 jan/2015
%%
global ASBS_INITDONE;
global ASBS_CENTROID;
global ASBS_FLATNESS;
global ASBS_ROLLOFF;
global ASBS_ZCR;
global ASBS_MFCC2;
global ASBS_MFCC3;
global ASBS_MFCC4;
global ASBS_MFCC5;
global ASBS_MFCC6;
global ASBS_MFCC7;
global ASBS_MFCC8;
global ASBS_MFCC9;
global ASBS_MFCC10;
global ASBS_MFCC11;
global ASBS_MFCC12;
global ASBS_MFCC13;
global ASBS_RMSRATIO;
% the process is not very efficient as I calculate all MFCC each time
% I need one

if nargin ~= 3
    disp ('Bad numbers of argumens');
    return;
end

if isempty(ASBS_INITDONE)
    disp ('Call asbsint first');
    return;
end

LineWidth = 1.2;

idx = asbsfeatureindex(feature);

[features fr ev] = asbsfeatures( wavefile, feature, true );
I = find(ev == 1);
x1 = features(I,:);
I = find(ev == 2);
x2 = features(I,:);
I = find(ev == 3);
x3 = features(I,:);
I = find(ev == 4);
x4 = features(I,:);

minX  = min([min(x1(:,idx)) min(x2(:,idx)) min(x3(:,idx)) min(x4(:,idx))]);
maxX  = max([max(x1(:,idx)) max(x2(:,idx)) max(x3(:,idx)) max(x4(:,idx))]);
stepX = (maxX - minX) / 50;
t = minX : stepX : maxX;
[x n] = hist(x1(:,idx), t);
plot (n, x./max(x), 'Color', [0 0 1], 'LineWidth', LineWidth);
hold on;
[x n] = hist(x2(:,idx), t);
plot (n, x./max(x), 'Color', [1 0 0], 'LineWidth', LineWidth);
hold on;
[x n] = hist(x3(:,idx), t);
plot (n, x./max(x), 'Color', [0 0.5 0], 'LineWidth', LineWidth);
hold on;
[x n] = hist(x4(:,idx), t);
plot (n, x./max(x), 'Color', [0 0.75 0.75], 'LineWidth', LineWidth);
switch feature
    case ASBS_CENTROID    
        title('Spectrum Centroid');
    case ASBS_ROLLOFF    
        title('Spectrum RollOff');
    case ASBS_FLATNESS    
        title('Spectrum Flatness');
    case ASBS_ZCR    
        title('Signal zero-crossing rate');
    case ASBS_MFCC2    
        title('MFCC #2');
    case ASBS_MFCC3    
        title('MFCC #3');
    case ASBS_MFCC4    
        title('MFCC #4');
    case ASBS_MFCC5    
        title('MFCC #5');
    case ASBS_MFCC6    
        title('MFCC #6');
    case ASBS_MFCC7    
        title('MFCC #7');
    case ASBS_MFCC8    
        title('MFCC #8');
    case ASBS_MFCC9    
        title('MFCC #9');
    case ASBS_MFCC10    
        title('MFCC #10');
    case ASBS_MFCC11    
        title('MFCC #11');
    case ASBS_MFCC12    
        title('MFCC #12');
    case ASBS_MFCC13    
        title('MFCC #13');
    case ASBS_RMSRATIO    
        title('RMS Ratio a 2.000 Hz');
end
if withlegend
    legend('Ins. bucal','Esp. bucal','Ins. nasal', 'Esp. nasal', 'Location', 'NorthEastOutside');
end 
    
%% EOF
