function asbsplotsignal ( filename, ps, varargin )
%%
% ASBSPLOTSIGNAL(FILENAME,PS,VARARGIN)
%
% Purpose:  Auxiliary function that plots time and
%           spectrograma of a signal
%           with optional vertical timemarks
%
% Inputs:   filename    - the wave file
%           ps          - plotSpectrograma? YES/NO (boolean)
%           vargarin    - (col1 col2 text)* 
%
% Output:   nothing
%
% Author:   juan a. Castro
% Version:  1.0 jan/2015
%%

% Chech that thwe numbers of parameters is OK
if (3 * round(double(nargin-2)/3) ~= nargin-2)
    disp ('Error en el nombre de parametres');
    return
end

[path name ext] = fileparts (filename);
if isempty( ext )
    filename = [filename '.wav'];
end

% Read wave file (with samplig rate and Bit Depth)
[wave, fs, nbits] = wavread(filename); 

% Set time scale (1/fs)
t=0:1/fs:(length(wave)-1)/fs;

% Plot the wave (time domain)
figure ('Color', [1 1 1]);
if ps
    subplot (211);
end
plot (t,wave);
xlim ([0 (length(wave)-1)/fs]);     % set axis X limit
xlabel('temps(s)', 'fontsize', 10); % Set X label
ylabel('Amplitud', 'fontsize', 10); % Set Y label

hold on
ylimit = ylim;
if nargin ~= 2
    ylimit (1,2) = ylimit (1,2) + 0.05;
    ylim (ylimit);
end    

totalMarks = (nargin-2) / 3;
i = 0;
while i < totalMarks
    % afegir indicadors d'inici fi 
    x = [varargin{i*3+1} varargin{i*3+1}];
    plot (x, ylim, ':r', 'Linewidth', 1);
    x = [varargin{i*3+2} varargin{i*3+2}];
    plot (x, ylim, ':r', 'Linewidth', 1);
    text(varargin{i*3+1}+(varargin{i*3+2}-varargin{i*3+1})/2, ...
        ylimit(1,2)-0.05, varargin{i*3+3}, 'Color', 'r');
    i = i + 1;
end
ylim (ylimit)

if ps
% Plot the wave (frequency domain)
    subplot(212);
    spectrogram(wave,hann(256),224,1024,fs,'yaxis') % use sampling fr.
end

%% EOF


