function [ratioHz1 ratioHz2 ratioHz3 ratioHz4] = ...
                                asbsrmsratios ( breathfile )
%%
% ASBSRMSRATIOS(BREATHFILE)
%
% Purpose:  Auxiliary function that calculates RMS average in steps
%           of 50 Hz frequency.
%
% Inputs:   BRATHFILE   - wave file
%           
% Output:   RATIOHZ1    - average energy for every 50 HZ bin frequency
%                         for bucal inspiration.
%           RATIOHZ2    - average energy for every 50 HZ bin frequency
%                         for bucal espiration.
%           RATIOHZ1    - average energy for every 50 HZ bin frequency
%                         for nasal inspiration.
%           RATIOHZ2    - average energy for every 50 HZ bin frequency
%                         for nasal espiration.
%
% Author:   juan a. Castro
% Version:  1.0 jan/2015
%%

global ASBS_SAMPLING;
global ASBS_WINDOW_SAMPLES;
global ASBS_OVERLAPPED;
global ASBS_THRESHOLD;

% append extension if needed
[path name ext] = fileparts (breathfile);
if isempty( ext )
    breathfile = [breathfile '.wav'];
end

% Read breath file
[x, fs, nbits] = wavread(breathfile); 

if fs ~= ASBS_SAMPLING
    disp('Sampling does not match global setting');
    return
end

% Read marks file
str = strfind(breathfile,'_');
marks = asbsimportxls([breathfile(1:str(1)-1) '.xlsx']);

if ASBS_OVERLAPPED, wpf = 2; else wpf = 1; end

% number of points in window
step = floor (ASBS_WINDOW_SAMPLES / wpf);

% loop x framed 
totalwindows = floor(length(x) / step);

% set output dimensions
ratios1         = zeros (totalwindows, 1);
ratios2         = zeros (totalwindows, 1);
ratios3         = zeros (totalwindows, 1);
ratios4         = zeros (totalwindows, 1);

L = floor(fs / 2 / 50);

ratioHz1 = zeros (L, 1);
ratioHz2 = zeros (L, 1);
ratioHz3 = zeros (L, 1);
ratioHz4 = zeros (L, 1);

idx = 1;
for fc = 0:50:fs/2
    j1 = 1;
    j2 = 1;
    j3 = 1;
    j4 = 1;
    imark = 1;
    for i = 0 : totalwindows - wpf
        a = i * step + 1;
        b = i * step + ASBS_WINDOW_SAMPLES;
        e = asbssignalrms(x(a:b));
        if (e >= ASBS_THRESHOLD)
            timea = a / fs;
            timeb = b / fs;

            while marks (imark, 1) < timeb
                imark = imark + 1;
            end
            if marks(imark, 1) == timeb
                event = 0;
            elseif timea < marks(imark-1, 1)
                event = 0;
            else
                event = marks(imark, 2);
            end
            XX = asbsspectrum(x(a:b));
            f = fs / 2 / length(XX);
            sample = floor(fc/f - 0.5);
            switch event
                case 1
                    ratios1(j1,1) = sum(XX(1:sample)) / sum(XX);
                    j1 =  j1 + 1;
                case 2
                    ratios2(j2,1) = sum(XX(1:sample)) / sum(XX);
                    j2 =  j2 + 1;
                case 3
                    ratios3(j3,1) = sum(XX(1:sample)) / sum(XX);
                    j3 =  j3 + 1;
                case 4
                    ratios4(j4,1) = sum(XX(1:sample)) / sum(XX);
                    j4 =  j4 + 1;
            end        
        end
    end
    ratioHz1 (idx, 1) = mean (ratios1(1:j1));
    ratioHz2 (idx, 1) = mean (ratios2(1:j2));
    ratioHz3 (idx, 1) = mean (ratios3(1:j3));
    ratioHz4 (idx, 1) = mean (ratios4(1:j4));
    idx = idx + 1;
end

%% EOF



        
        
        


