function [ ev p ] = asbsstmactions (value, energy, timeevent )
%%
% ASBSSTMACTIONS(VALUE,EBERGY,TIMEEVENT)
%
% Purpose:  This is the prediction state machine
%
% Inputs:   VALUE       - Prediction from KNN classification
%           ENERGY      - Energy of frame
%           TIMEEVENT   - Time of frame
%
% Output:   EV          - Prediction from state machine
%                         A value of 0 means that it is not final
%                         state.
%           P           - Calculated probability of success if final
%                         state.
%
% Author:   juan a. Castro
% Version:  1.0 jan/2015
%%

global ASBS_STM_STATE;
global ASBS_STM_OLDENERGY;
global ASBS_STM_OLDVALUE;
global ASBS_STM_NC0S;
global ASBS_STM_NCN0S;
global ASBS_STM_N1S;
global ASBS_STM_N2S;
global ASBS_STM_N3S;
global ASBS_STM_N4S;
global ASBS_STM_NCCE;
global ASBS_STM_NCDE;
global ASBS_STM_MINIMUM_CONSECUTIVES;

oldNC0S  = ASBS_STM_NC0S;
oldNCN0S = ASBS_STM_NCN0S;

% Do accumulatives if states <> 1 and event <> 0
if ASBS_STM_STATE ~= 1 || ASBS_STM_OLDVALUE == 0 || ... 
        (ASBS_STM_STATE == 1 && value ~= 0)
    switch (value)
        case 0
            if ASBS_STM_OLDVALUE == 0
                ASBS_STM_NC0S = ASBS_STM_NC0S + 1;
            else
                ASBS_STM_NC0S = 0;
            end
        case 1
            ASBS_STM_N1S = ASBS_STM_N1S + 1;
        case 2
            ASBS_STM_N2S = ASBS_STM_N2S + 1;
        case 3
            ASBS_STM_N3S = ASBS_STM_N3S + 1;
        case 4
            ASBS_STM_N4S = ASBS_STM_N4S + 1;
    end
    
    if  energy > ASBS_STM_OLDENERGY;
        ASBS_STM_NCCE = ASBS_STM_NCCE + 1;
    else
        ASBS_STM_NCDE = ASBS_STM_NCDE + 1;
    end
    ASBS_STM_OLDENERGY = energy;
end

if value ~= 0 && ASBS_STM_OLDVALUE ~= 0
    ASBS_STM_NCN0S = ASBS_STM_NCN0S + 1;
else
    ASBS_STM_NCN0S = 0;
end
    
p = 0;    
switch (ASBS_STM_STATE)
    case 0
        if value == 0
            ASBS_STM_STATE = 1;
        end
        ev = 0;
    case 1
        if value == 0 && ASBS_STM_OLDVALUE ~= 0
            if oldNCN0S > ASBS_STM_MINIMUM_CONSECUTIVES
                %% prendre resolucion
                total = ASBS_STM_N1S + ASBS_STM_N2S + ...
                    ASBS_STM_N3S + ASBS_STM_N4S;
                p1 = ASBS_STM_N1S / total;
                p2 = ASBS_STM_N2S / total;
                p3 = ASBS_STM_N3S / total;
                p4 = ASBS_STM_N4S / total;
                pBucal = (ASBS_STM_N1S + ASBS_STM_N2S) / total;
                pNasal = (ASBS_STM_N3S + ASBS_STM_N4S) / total;
                pIns   = (ASBS_STM_N1S + ASBS_STM_N3S) / total;
                pEsp   = (ASBS_STM_N2S + ASBS_STM_N4S) / total;
                pIns2  = ASBS_STM_NCCE / ...
                    (ASBS_STM_NCDE + ASBS_STM_NCCE);
                pEsp2  = ASBS_STM_NCDE / ...
                    (ASBS_STM_NCDE + ASBS_STM_NCCE);

                pBucalIns = 0.70 * p1 + 0.10 * pBucal + ...
                            0.10 * pIns + 0.10 * pIns2;
                pBucalEsp = 0.70 * p2 + 0.10 * pBucal + ...
                            0.10 * pEsp + 0.10 * pEsp2;
                pNasalIns = 0.70 * p3 + 0.10 * pNasal + ...
                            0.10 * pIns + 0.10 * pIns2;
                pNasalEsp = 0.70 * p4 + 0.10 * pNasal + ...
                            0.10 * pEsp + 0.10 * pEsp2;
        
                maxp = max([pBucalIns pBucalEsp pNasalIns pNasalEsp]);
                p = maxp;
                switch maxp
                    case pBucalIns
                        maxp = 1;
                    case pBucalEsp
                        maxp = 2;
                    case pNasalIns
                        maxp = 3;
                    case pNasalEsp
                        maxp = 4;
                end
                %%%
                ev = maxp;
                asbsstminit();
                ASBS_STM_STATE = 2;
            else
                asbsstminit();
                ev = 0;
                ASBS_STM_STATE = 2;
            end
        else
            ASBS_STM_STATE = 1;
            ev = 0;
        end
    case 2
        ASBS_STM_STATE = 1;
        ev = 0;
end

ASBS_STM_OLDVALUE = value;
        
%% EOF
